==> wire-grpc-client-3.2.0-javadoc.jar: wire-schema/com.squareup.wire.schema/-extend/index.md <==
[wire-schema](../../index.md) / [com.squareup.wire.schema](../index.md) / [Extend](./index.md)

# Extend

`class Extend`

### Properties

| Name | Summary |
|---|---|
| [documentation](documentation.md) | `val documentation: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [fields](fields.md) | `val fields: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`Field`](../-field/index.md)`>` |
| [location](location.md) | `val location: `[`Location`](../-location/index.md) |
| [name](name.md) | `val name: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [type](type.md) | `var type: `[`ProtoType`](../-proto-type/index.md)`?` |

### Functions

| Name | Summary |
|---|---|
| [link](link.md) | `fun link(linker: `[`Linker`](../-linker/index.md)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |
| [retainAll](retain-all.md) | `fun retainAll(schema: `[`Schema`](../-schema/index.md)`, markSet: `[`MarkSet`](../-mark-set/index.md)`): `[`Extend`](./index.md)`?` |
| [validate](validate.md) | `fun validate(linker: `[`Linker`](../-linker/index.md)`, syntaxRules: `[`SyntaxRules`](../-syntax-rules/index.md)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |

### Companion Object Functions

| Name | Summary |
|---|---|
| [fromElements](from-elements.md) | `fun fromElements(packageName: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`?, extendElements: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`ExtendElement`](../../com.squareup.wire.schema.internal.parser/-extend-element/index.md)`>): <ERROR CLASS>` |
| [toElements](to-elements.md) | `fun toElements(extendList: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`Extend`](./index.md)`>): <ERROR CLASS>` |

==> wire-grpc-client-3.4.0-javadoc.jar: wire-schema/com.squareup.wire.schema/-extend/index.md <==
[wire-schema](../../index.md) / [com.squareup.wire.schema](../index.md) / [Extend](./index.md)

# Extend

`data class Extend`

### Constructors

| Name | Summary |
|---|---|
| [&lt;init&gt;](-init-.md) | `Extend(location: `[`Location`](../-location/index.md)`, documentation: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`, name: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`, fields: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`Field`](../-field/index.md)`>)` |

### Properties

| Name | Summary |
|---|---|
| [documentation](documentation.md) | `val documentation: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [fields](fields.md) | `val fields: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`Field`](../-field/index.md)`>` |
| [location](location.md) | `val location: `[`Location`](../-location/index.md) |
| [name](name.md) | `val name: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [type](type.md) | `var type: `[`ProtoType`](../-proto-type/index.md)`?` |

### Functions

| Name | Summary |
|---|---|
| [link](link.md) | `fun link(linker: `[`Linker`](../-linker/index.md)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |
| [linkOptions](link-options.md) | `fun linkOptions(linker: `[`Linker`](../-linker/index.md)`, syntaxRules: `[`SyntaxRules`](../-syntax-rules/index.md)`, validate: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |
| [retainAll](retain-all.md) | `fun retainAll(schema: `[`Schema`](../-schema/index.md)`, markSet: `[`MarkSet`](../-mark-set/index.md)`): `[`Extend`](./index.md)`?` |
| [retainLinked](retain-linked.md) | `fun retainLinked(linkedFields: `[`Set`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)`<`[`Field`](../-field/index.md)`>): `[`Extend`](./index.md)`?` |
| [validate](validate.md) | `fun validate(linker: `[`Linker`](../-linker/index.md)`, syntaxRules: `[`SyntaxRules`](../-syntax-rules/index.md)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |

### Companion Object Functions

| Name | Summary |
|---|---|
| [fromElements](from-elements.md) | `fun fromElements(packageName: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`?, extendElements: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`ExtendElement`](../../com.squareup.wire.schema.internal.parser/-extend-element/index.md)`>): <ERROR CLASS>` |
| [toElements](to-elements.md) | `fun toElements(extendList: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`Extend`](./index.md)`>): <ERROR CLASS>` |
